"""
snapparquet — fast, column-pruned Parquet (and CSV) reads for analytics.

Use :func:`read_tabular` for a single file, :func:`read_tabular_many` for batches,
and :func:`schema_column_names` for footer-only schema introspection.
"""

from snapparquet._version import __version__
from snapparquet.readers import (
    read_csv,
    read_parquet,
    read_parquet_many,
    read_tabular,
    read_tabular_many,
)
from snapparquet.schema import (
    column_is_integer_type,
    intersect_columns,
    norm_col,
    schema_column_names,
    schema_has_all,
    schema_matches_any_group,
)

__all__ = [
    "__version__",
    "column_is_integer_type",
    "intersect_columns",
    "norm_col",
    "read_csv",
    "read_parquet",
    "read_parquet_many",
    "read_tabular",
    "read_tabular_many",
    "schema_column_names",
    "schema_has_all",
    "schema_matches_any_group",
]
